Bindings to the ScreenSaver framework
See Apple’s docs and the general docs on framework crates for more information.
Structs
- Screen
Saver Defaults ScreenSaverDefaults - A class that defines a set of methods for saving and restoring user defaults for screen savers.
- Screen
Saver View ScreenSaverViewandobjc2-app-kit - An abstract class that defines the interface for subclassers to interact with the screen saver infrastructure.